@@ -11,7 +11,7 @@ class Button(Field):
 
     @use_after
     @use_before
-    def click(self):
+    def click(self) -> None:
         """Use Appium's click method.
 
         Example:
